Package 'gaml2r'

Title: Parse GAML Files
Description: Open and parse data from a Generalized Analytical Markup Language (GAML) files.
Authors: Tom Wilson [aut, cre]
Maintainer: Tom Wilson <[email protected]>
License: GPL (>= 3)
Version: 0.1.3
Built: 2026-06-01 16:45:49 UTC
Source: https://github.com/wilsontom/gaml2r

Help Index


Extract the GAML Conversion Parameters

Description

Extract the GAML Conversion Parameters

Usage

get_parameters(gaml_file)

Arguments

gaml_file

a .gaml file

Value

a tbl_df of GAML conversion parameters


Extract the SHA1 Integrity Algorithm

Description

Extract the SHA1 Integrity Algorithm

Usage

get_sha1(gaml_file)

Arguments

gaml_file

a .gaml file

Value

an alpha-numeric string of the SHA1 integrity algorithm for the GAML file


Open GAML File

Description

Open and extract data from a GAML file containing High Performance Liquid Chromatography (HPLC) Refractive Index (RI) data

Usage

openFile(gaml_file, output = "list", include_injection_info = FALSE)

Arguments

gaml_file

a .gaml file

output

a character string of either list (default) of tbl_df

include_injection_info

logical (default = FALSE). If TRUE sample injection information is also included

Value

if output = list then a nested list is returned. If output = tbl_df then all data is returned in a single long format tbl_df