| Title: | Parse GAML Files |
|---|---|
| Description: | Open and parse data from a Generalized Analytical Markup Language (GAML) files. |
| Authors: | Tom Wilson [aut, cre] |
| Maintainer: | Tom Wilson <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.3 |
| Built: | 2026-06-01 16:45:49 UTC |
| Source: | https://github.com/wilsontom/gaml2r |
Extract the GAML Conversion Parameters
get_parameters(gaml_file)get_parameters(gaml_file)
gaml_file |
a |
a tbl_df of GAML conversion parameters
Extract the SHA1 Integrity Algorithm
get_sha1(gaml_file)get_sha1(gaml_file)
gaml_file |
a |
an alpha-numeric string of the SHA1 integrity algorithm for the GAML file
Open and extract data from a GAML file containing High Performance Liquid Chromatography (HPLC) Refractive Index (RI) data
openFile(gaml_file, output = "list", include_injection_info = FALSE)openFile(gaml_file, output = "list", include_injection_info = FALSE)
gaml_file |
a |
output |
a character string of either |
include_injection_info |
logical (default = |
if output = list then a nested list is returned. If output = tbl_df then all data is returned in a single long format tbl_df